Home — StarCluster v0.92rc1 documentation

### Navigation

- index
- Home |
- Install |
- Config |
- Examples |
- Support

# StarCluster documentation (v. 0.92rc1)

Welcome to StarCluster's main documentation. StarCluster is a utility for creating and managing general purpose computing clusters hosted on Amazon's Elastic Compute Cloud (EC2). StarCluster utilizes Amazon's EC2 web service to create and destroy clusters of Linux virtual machines on demand. StarCluster aims at being simple, hackable, and extensible.

StarCluster is under constant development. The main implemented features are:

- Easily Create and Configure Clusters on EC2 - Launch multiple clusters of 1-100 nodes using a simple start command
- Automated Configuration - Configures users, NFS shares, Sun Grid Engine queuing system, password-less ssh between machines, etc
- Attach and NFS Share EBS Volumes - Support for attaching and NFS-sharing both partitioned and unpartitioned Amazon Elastic Block Storage (EBS) volumes for persistent storage across a cluster
- Publicly available Amazon Machine Images (AMI) - Configured for scientific computing. Includes OpenMPI, ATLAS, Lapack, NumPy, SciPy, and other useful libraries
- User-contributed Plugins - Plugins allow users to perform additional setup routines on the cluster after StarCluster's defaults. Plugins are called when adding/removing a node as well as when restarting/shutting down the entire cluster
- EBS-Backed Clusters - Support for starting/stopping EBS-backed clusters on EC2
- Cluster Compute/GPU Instances - Support for the new Cluster Compute and GPU Cluster Compute instance types
- Add/Remove Nodes - Support for adding/removing nodes to a running cluster
- Restart Clusters - Reboot and reconfigure a running cluster
- Elastic Load Balancing - Shrink and expand clusters based on Sun Grid Engine queue statistics
- Multiple Instance Types - Specify multiple instance types on a per-node basis.

## User Sections

Overview Introduction to StarCluster. Install instructions How to install StarCluster. Quick-Start Tutorial A Quick-Start tutorial for StarCluster newcomers. | Guides Task oriented guides User Manual Detailed description of the command line interface. Plugins Plugin documentation FAQ Frequently Asked Questions

## StarCluster development

Contribute Taking part in StarCluster's development. Hacking Design rationales, source organization. | Features Current and planned features. TODO Remaining development tasks.

## Indices and Tables

Table of Contents Lists all sections and subsections. Search Page Search this documentation. | Index All functions, classes, terms.

### Navigation

- index
- Home |
- Install |
- Config |
- Examples |
- Support